@@ -1,12 +1,12 @@
 /**
  * @file agShell.c
  *
- *  Time-stamp:        "2011-10-08 10:46:21 bkorb"
+ *  Time-stamp:        "2012-01-29 20:36:21 bkorb"
  *
  *  Manage a server shell process
  *
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2012 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -21,6 +21,111 @@
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
+static char * cur_dir = NULL;
+
+/*=gfunc chdir
+ *
+ * what:   Change current directory
+ *
+ * exparg: dir, new directory name
+ *
+ * doc:  Sets the current directory for AutoGen.  Shell commands will run
+ *       from this directory as well.  This is a wrapper around the Guile
+ *       native function.  It returns its directory name argument and
+ *       fails the program on failure.
+=*/
+SCM
+ag_scm_chdir(SCM dir)
+{
+    static char const zChdirDir[] = "chdir directory";
+
+    scm_chdir(dir);
+
+    /*
+     *  We're still here, so we have a valid argument.
+     */
+    if (cur_dir != NULL)
+        free(cur_dir);
+    {
+        char const * pz = ag_scm2zchars(dir, zChdirDir);
+        cur_dir = malloc(AG_SCM_STRLEN(dir) + 1);
+        strcpy((char*)cur_dir, pz);
+    }
+    return dir;
+}
+
+/*=gfunc shell
+ *
+ * what:  invoke a shell script
+ * general_use:
+ *
+ * exparg: command, shell command - the result value is the stdout output.
+ *
+ * doc:
+ *  Generate a string by writing the value to a server shell and reading the
+ *  output back in.  The template programmer is responsible for ensuring that
+ *  it completes within 10 seconds.  If it does not, the server will be
+ *  killed, the output tossed and a new server started.
+ *
+ *  Please note: This is the same server process used by the '#shell'
+ *  definitions directive and backquoted @code{`} definitions.  There may be
+ *  left over state from previous shell expressions and the @code{`}
+ *  processing in the declarations.  However, a @code{cd} to the original
+ *  directory is always issued before the new command is issued.
+ *
+ *  Also note:  When initializing, autogen will set the environment
+ *  variable "AGexe" to the full path of the autogen executable.
+=*/
+SCM
+ag_scm_shell(SCM cmd)
+{
+#ifndef SHELL_ENABLED
+    return cmd;
+#else
+    if (! AG_SCM_STRING_P(cmd))
+        return SCM_UNDEFINED;
+    {
+        char* pz = shell_cmd(ag_scm2zchars(cmd, "command"));
+        cmd   = AG_SCM_STR02SCM(pz);
+        AGFREE((void*)pz);
+        return cmd;
+    }
+#endif
+}
+
+/*=gfunc shellf
+ *
+ * what:  format a string, run shell
+ * general_use:
+ *
+ * exparg: format, formatting string
+ * exparg: format-arg, list of arguments to formatting string, opt, list
+ *
+ * doc:  Format a string using arguments from the alist,
+ *       then send the result to the shell for interpretation.
+=*/
+SCM
+ag_scm_shellf(SCM fmt, SCM alist)
+{
+    int   len = scm_ilength(alist);
+    char* pz;
+
+#ifdef DEBUG_ENABLED
+    if (len < 0)
+        AG_ABEND(SHELLF_BAD_ALIST_MSG);
+#endif
+
+    pz  = ag_scm2zchars(fmt, "format");
+    fmt = run_printf(pz, len, alist);
+
+#ifdef SHELL_ENABLED
+    pz  = shell_cmd(ag_scm2zchars(fmt, "shell script"));
+    fmt = AG_SCM_STR02SCM(pz);
+    AGFREE((void*)pz);
+#endif
+    return fmt;
+}
+
 #ifndef SHELL_ENABLED
 HIDE_FN(void closeServer(void) {;})
 
@@ -38,14 +143,24 @@ static tpfPair      serv_pair     = { NULL, NULL };
 static pid_t        serv_id       = NULLPROCESS;
 static ag_bool      was_close_err = AG_FALSE;
 static int          log_ct        = 0;
-static char const   log_sep_fmt[] = "\n\n* * * * LOG ENTRY %d * * * *\n";
-static char const   cmd_fmt[]     = "cd %s\n%s\n\necho\necho %s - %d\n";
 static char const * last_cmd      = NULL;
 
 /* = = = START-STATIC-FORWARD = = = */
 static void
 handle_signal(int signo);
 
+static void
+set_orig_dir(void);
+
+static ag_bool
+send_cmd_ok(char const * cmd);
+
+static void
+start_server_cmd_trace(void);
+
+static void
+send_server_init_cmds(void);
+
 static void
 server_setup(void);
 
@@ -58,7 +173,7 @@ server_open(tFdPair* pPair, char const ** ppArgs);
 static pid_t
 server_fp_open(tpfPair* pfPair, char const ** ppArgs);
 
-static void
+static inline void
 realloc_text(char ** p_txt, size_t * p_sz, size_t need_len);
 
 static char*
@@ -112,43 +227,118 @@ handle_signal(int signo)
 {
     static int timeout_limit = 5;
     if ((signo == SIGALRM) && (--timeout_limit <= 0))
-        AG_ABEND("Server shell timed out 5 times");
+        AG_ABEND(TOO_MANY_TIMEOUTS_MSG);
 
-    fprintf(pfTrace, "Closing server:  %s signal (%d) received\n",
-            strsignal(signo), signo);
+    fprintf(pfTrace, SHELL_DIE_ON_SIGNAL_FMT, strsignal(signo), signo);
     was_close_err = AG_TRUE;
 
-    (void)fputs("\nLast command issued:\n", pfTrace);
+    (void)fputs(SHELL_LAST_CMD_MSG, pfTrace);
     {
         char const* pz = (last_cmd == NULL)
-            ? "?? unknown ??\n" : last_cmd;
-        fprintf(pfTrace, cmd_fmt, pCurDir, pz, zShDone, log_ct);
+            ? SHELL_UNK_LAST_CMD_MSG : last_cmd;
+        fprintf(pfTrace, SHELL_CMD_FMT, cur_dir, pz, SH_DONE_MARK, log_ct);
     }
     last_cmd = NULL;
     close_server_shell();
 }
 
+/**
+ * first time starting a server shell, we get our current directory.
+ * That value is kept, but may be changed via a (chdir "...") scheme call.
+ */
+static void
+set_orig_dir(void)
+{
+    char * p = malloc(AG_PATH_MAX);
+    if (p == NULL)
+        AG_ABEND(SET_ORIG_DIR_NO_MEM_MSG);
 
+    cur_dir = getcwd(p, AG_PATH_MAX);
+
+    if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL)
+        fputs(TRACE_SHELL_FIRST_START, pfTrace);
+}
+
+/**
+ * Send a command string down to the server shell
+ */
+static ag_bool
+send_cmd_ok(char const * cmd)
+{
+    last_cmd = cmd;
+    fprintf(serv_pair.pfWrite, SHELL_CMD_FMT, cur_dir, last_cmd,
+            SH_DONE_MARK, ++log_ct);
+
+    if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL) {
+        fprintf(pfTrace, LOG_SEP_FMT, log_ct);
+        fprintf(pfTrace, SHELL_CMD_FMT, cur_dir, last_cmd,
+                SH_DONE_MARK, log_ct);
+    }
+
+    (void)fflush(serv_pair.pfWrite);
+    if (was_close_err)
+        fprintf(pfTrace, CMD_FAIL_FMT, cmd);
+    return ! was_close_err;
+}
+
+/**
+ * Tracing level is TRACE_EVERYTHING, so send the server shell
+ * various commands to start "set -x" tracing and display the
+ * trap actions.
+ */
+static void
+start_server_cmd_trace(void)
+{
+    fputs(TRACE_XTRACE_MSG, pfTrace);
+    if (send_cmd_ok(SHELL_XTRACE_CMDS)) {
+        char * pz = load_data();
+        fputs(SHELL_RES_DISCARD_MSG, pfTrace);
+        fprintf(pfTrace, TRACE_TRAP_STATE_FMT, pz);
+        AGFREE((void*)pz);
+    }
+}
+
+/**
+ * Send down the initialization string with our PID in it, as well
+ * as the full path name of the autogen executable.
+ */
+static void
+send_server_init_cmds(void)
+{
+    was_close_err = AG_FALSE;
+
+    {
+        char * pzc = AGALOC(SHELL_INIT_STR_LEN
+                            + 11 // log10(1 << 32) + 1
+                            + strlen(autogenOptions.pzProgPath),
+                            "server init");
+        sprintf(pzc, SHELL_INIT_STR, (unsigned int)getpid(),
+                autogenOptions.pzProgPath,
+                (pfDepends == NULL) ? "" : pzDepFile);
+
+        if (send_cmd_ok(pzc))
+            AGFREE((void*)load_data());
+        AGFREE(pzc);
+    }
+
+    if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL)
+        fputs(SHELL_RES_DISCARD_MSG, pfTrace);
+
+    if (OPT_VALUE_TRACE >= TRACE_EVERYTHING)
+        start_server_cmd_trace();
+}
+
+/**
+ * Perform various initializations required when starting
+ * a new server shell process.
+ */
 static void
 server_setup(void)
 {
-    {
-        static int do_once = 0;
-        if (do_once == 0) {
-            char* p = malloc(AG_PATH_MAX);
-            if (p == NULL)
-                AG_ABEND("cannot allocate path name");
-
-            pCurDir = (tpChar)getcwd(p, AG_PATH_MAX);
-
-            if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL)
-                fputs("\nServer First Start\n", pfTrace);
-
-            do_once = 1;
-        }
-        else if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL)
-            fputs("\nServer Restart\n", pfTrace);
-    }
+    if (cur_dir == NULL)
+        set_orig_dir();
+    else if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL)
+        fputs(SHELL_RESTART_MSG, pfTrace);
 
     {
         struct sigaction new_sa;
@@ -159,61 +349,23 @@ server_setup(void)
         (void)sigaction(SIGALRM, &new_sa, NULL);
     }
 
-    was_close_err = AG_FALSE;
+    send_server_init_cmds();
 
-    {
-        char* pz;
-        last_cmd = shell_init_str;
-        sprintf(shell_init_str + shell_init_len, "%u\n",
-                (unsigned int)getpid());
-        fprintf(serv_pair.pfWrite, cmd_fmt, pCurDir, last_cmd,
-                zShDone, ++log_ct);
-
-        if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL) {
-            fprintf(pfTrace, log_sep_fmt, log_ct);
-            fprintf(pfTrace, cmd_fmt, pCurDir, last_cmd, zShDone, log_ct);
-        }
-
-        (void)fflush(serv_pair.pfWrite);
-        pz = load_data();
-        if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL)
-            fputs("(result discarded)\n", pfTrace);
-        AGFREE((void*)pz);
-    }
-
-    if (OPT_VALUE_TRACE >= TRACE_EVERYTHING) {
-        static char const zSetup[] =
-            "set -x\n"
-            "trap\n"
-            "echo server setup done\n";
-        char* pz;
-
-        fputs("Server traps set\n", pfTrace);
-        last_cmd = zSetup;
-        fprintf(serv_pair.pfWrite, cmd_fmt, pCurDir, last_cmd,
-                zShDone, ++log_ct);
-        if (pfTrace != stderr) {
-            fprintf(pfTrace, log_sep_fmt, log_ct);
-            fprintf(pfTrace, cmd_fmt, pCurDir, last_cmd, zShDone, log_ct);
-        }
-
-        (void)fflush(serv_pair.pfWrite);
-        pz = load_data();
-        if (pfTrace != stderr)
-            fputs("(result discarded)\n", pfTrace);
-        fprintf(pfTrace, "Trap state:\n%s\n", pz);
-        AGFREE((void*)pz);
-    }
     last_cmd = NULL;
 }
 
-
 /**
  *  Given an FD for an inferior process to use as stdin,
  *  start that process and return a NEW FD that that process
  *  will use for its stdout.  Requires the argument vector
  *  for the new process and, optionally, a pointer to a place
  *  to store the child's process id.
+ *
+ * @param stdinFd the file descriptor for the process' stdin
+ * @param ppArgs  The program and argument vector
+ * @param pChild  where to stash the child process PID
+ *
+ * @returns the read end of a pipe the child process uses for stdout
  */
 static int
 chain_open(int stdinFd, char const ** ppArgs, pid_t * pChild)
@@ -274,7 +426,7 @@ chain_open(int stdinFd, char const ** ppArgs, pid_t * pChild)
         close(stdinFd);
         close(stdoutPair.writeFd);
         if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL)
-            fprintf(pfTrace, "Server shell is pid %u\n", (unsigned int)chId);
+            fprintf(pfTrace, TRACE_SHELL_PID_FMT, (unsigned int)chId);
 
         fflush(pfTrace);
         return stdoutPair.readFd;
@@ -312,7 +464,7 @@ chain_open(int stdinFd, char const ** ppArgs, pid_t * pChild)
     setvbuf(stdout, NULL, _IONBF, (size_t)0);
 
     if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL) {
-        fprintf(pfTrace, "Server shell %s starts\n", pzShell);
+        fprintf(pfTrace, TRACE_SHELL_STARTS_FMT, pzShell);
 
         fflush(pfTrace);
     }
@@ -323,7 +475,6 @@ chain_open(int stdinFd, char const ** ppArgs, pid_t * pChild)
     return -1;
 }
 
-
 /**
  *  Given a pointer to an argument vector, start a process and
  *  place its stdin and stdout file descriptors into an fd pair
@@ -371,16 +522,11 @@ server_fp_open(tpfPair* pfPair, char const ** ppArgs)
     return chId;
 }
 
-static void
+static inline void
 realloc_text(char ** p_txt, size_t * p_sz, size_t need_len)
 {
-    size_t sz = (*p_sz + need_len + 0xFFF) & ~0xFFF;
-    void * p = AGREALOC((void*)*p_txt, sz, "expanding text");
-    if (p == NULL)
-        AG_ABEND(aprf(zAllocWhat, sz, "Realloc Text Block"));
-
-    *p_txt = p;
-    *p_sz  = sz;
+    *p_sz  = (*p_sz + need_len + 0xFFF) & ~0xFFF;
+    *p_txt = AGREALOC((void*)*p_txt, *p_sz, "expand text");
 }
 
 /**
@@ -423,8 +569,7 @@ load_data(void)
                 break;
 
             if ((OPT_VALUE_TRACE >= TRACE_SERVER_SHELL) || (retryCt++ > 0))
-                fprintf(pfTrace, "fs err %d (%s) reading from server shell\n",
-                         errno, strerror(errno));
+                fprintf(pfTrace, SHELL_READ_ERR_FMT, errno, strerror(errno));
 
             if (feof(serv_pair.pfRead) || (retryCt > 32))
                 break;
@@ -435,7 +580,7 @@ load_data(void)
         /*
          *  Check for magic character sequence indicating 'DONE'
          */
-        if (strncmp(zLine, zShDone, STRSIZE(zShDone)) == 0)
+        if (strncmp(zLine, SH_DONE_MARK, SH_DONE_MARK_LEN) == 0)
             break;
 
         {
@@ -454,7 +599,7 @@ load_data(void)
          *  Stop now if server timed out or if we are at EOF
          */
         if ((serv_id == NULLPROCESS) || feof(serv_pair.pfRead)) {
-            fputs("feof on data load\n", pfTrace);
+            fputs(SHELL_NO_END_MARK_MSG, pfTrace);
             break;
         }
     }
@@ -463,17 +608,16 @@ load_data(void)
      *  Trim off all trailing white space and shorten the buffer
      *  to the size actually used.
      */
-    while ((pzScan > pzText) && IS_WHITESPACE_CHAR(pzScan[-1])) pzScan--;
+    while (  (pzScan > pzText)
+          && IS_WHITESPACE_CHAR(pzScan[-1]))
+        pzScan--;
     textSize = (pzScan - pzText) + 1;
-
-    if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL) {
-        fprintf(pfTrace, "\n= = = RESULT %d bytes:\n%s%s\n"
-                "= = = = = = = = = = = = = = =\n",
-                (int)textSize, pzText, zLine);
-    }
-
     *pzScan  = NUL;
-    return AGREALOC((void*)pzText, textSize, "resizing text output");
+
+    if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL)
+        fprintf(pfTrace, TRACE_SHELL_RESULT_MSG, (int)textSize, pzText, zLine);
+
+    return AGREALOC((void*)pzText, textSize, "resize output");
 }
 
 
@@ -486,16 +630,12 @@ load_data(void)
 LOCAL char*
 shell_cmd(char const * pzCmd)
 {
-    static char const cmd_fail_fmt[] =
-        "CLOSING SHELL SERVER - command failure:\n\t%s\n";
-
     /*
      *  IF the shell server process is not running yet,
      *  THEN try to start it.
      */
     if (serv_id == NULLPROCESS) {
-        static char const ps4_z[] = "PS4=>${FUNCNAME:-ag}> ";
-        putenv((char *)ps4_z);
+        putenv((char *)SHELL_SET_PS4_FMT);
         serv_id = server_fp_open(&serv_pair, serverArgs);
         if (serv_id > 0)
             server_setup();
@@ -517,21 +657,8 @@ shell_cmd(char const * pzCmd)
      *  send the supplied command, and then
      *  have it output a special marker that we can find.
      */
-    last_cmd = pzCmd;
-    fprintf(serv_pair.pfWrite, cmd_fmt, pCurDir, pzCmd, zShDone, ++log_ct);
-
-    if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL) {
-        fprintf(pfTrace, log_sep_fmt, log_ct);
-        fprintf(pfTrace, cmd_fmt, pCurDir, pzCmd, zShDone, log_ct);
-    }
-
-    if (serv_pair.pfWrite != NULL)
-        fflush(serv_pair.pfWrite);
-
-    if (was_close_err) {
-        fprintf(pfTrace, cmd_fail_fmt, pzCmd);
+    if (! send_cmd_ok(pzCmd))
         return NULL;
-    }
 
     /*
      *  Now try to read back all the data.  If we fail due to either
@@ -540,14 +667,14 @@ shell_cmd(char const * pzCmd)
     {
         char* pz = load_data();
         if (pz == NULL) {
-            fprintf(pfTrace, cmd_fail_fmt, pzCmd);
+            fprintf(pfTrace, CMD_FAIL_FMT, pzCmd);
             close_server_shell();
             pz = (char*)AGALOC(1, "Text Block");
 
             *pz = NUL;
 
         } else if (was_close_err)
-            fprintf(pfTrace, cmd_fail_fmt, pzCmd);
+            fprintf(pfTrace, CMD_FAIL_FMT, pzCmd);
 
         last_cmd = NULL;
         return pz;
