@@ -2,7 +2,7 @@
 /**
  * @file expPrint.c
  *
- *  Time-stamp:        "2011-01-20 16:21:45 bkorb"
+ *  Time-stamp:        "2012-01-14 10:45:59 bkorb"
  *
  *  The following code is necessary because the user can give us
  *  a printf format requiring a string pointer yet fail to provide
@@ -11,7 +11,7 @@
  *  a core dump :-)
  *
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2012 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -69,39 +69,33 @@ safePrintf(char** ppzBuf, char const * pzFmt, void** argV)
         sigaction(SIGSEGV, &sa, &saSave2);
     }
 
-    {
-        static char const zBadArgs[] = "Bad args to sprintf";
-        static char const zBadFmt[]  =
-            "%s ERROR:  %s processing printf format:\n\t%s\n";
+    /*
+     *  IF the sprintfv call below is going to address fault,
+     *  THEN ...
+     */
+    if (sigsetjmp(printJumpEnv, 0) != 0) {
+#ifndef HAVE_STRSIGNAL
+        extern char* strsignal(int signo);
+#endif
+        /*
+         *  IF the fprintf command in the then clause has not failed yet,
+         *  THEN perform that fprintf
+         */
+        if (sigsetjmp(printJumpEnv, 0) == 0)
+            fprintf(pfTrace, SAFE_PRINTF_BAD_FMT, pzProg,
+                    strsignal(printJumpSignal), pzFmt);
 
         /*
-         *  IF the sprintfv call below is going to address fault,
-         *  THEN ...
+         *  The "sprintfv" command below faulted, so we exit
          */
-        if (sigsetjmp(printJumpEnv, 0) != 0) {
-#ifndef HAVE_STRSIGNAL
-            extern char* strsignal(int signo);
-#endif
-            /*
-             *  IF the fprintf command in the then clause has not failed yet,
-             *  THEN perform that fprintf
-             */
-            if (sigsetjmp(printJumpEnv, 0) == 0)
-                fprintf(pfTrace, zBadFmt, pzProg,
-                        strsignal(printJumpSignal), pzFmt);
-
-            /*
-             *  The "sprintfv" command below faulted, so we exit
-             */
-            AG_ABEND(zBadArgs);
-        }
+        AG_ABEND(SAFE_PRINTF_BAD_ARGS);
     }
 #endif /* ! defined(DEBUG_ENABLED) */
 
     {
         int printSize = asprintfv(ppzBuf, pzFmt, (snv_constpointer*)argV);
         if ((printSize & ~0xFFFFFU) != 0) /* 1MB max */
-            AG_ABEND(aprf("asprintfv returned 0x%08X\n", printSize));
+            AG_ABEND(aprf(ASPRINTFV_FAIL_FMT, printSize));
 
 #if ! defined(DEBUG_ENABLED)
         sigaction(SIGBUS,  &saSave1, NULL);
@@ -132,11 +126,12 @@ run_printf(char const * pzFmt, int len, SCM alist)
         switch (ag_scm_type_e(car)) {
         default:
         case GH_TYPE_UNDEFINED:
-            *(argp++) = (char*)"???";
+            *(argp++) = (char*)RUN_PRINTF_HUH;
             break;
 
         case GH_TYPE_BOOLEAN:
-            *(argp++) = (void*)((car == SCM_BOOL_F) ? "#f" : "#t");
+            *(argp++) = (void*)((car == SCM_BOOL_F)
+                                ? SCM_FALSE_STR : SCM_TRUE_STR);
             break;
 
         case GH_TYPE_CHAR:
@@ -144,7 +139,7 @@ run_printf(char const * pzFmt, int len, SCM alist)
             break;
 
         case GH_TYPE_PAIR:
-            *(argp++) = (char*)"..";
+            *(argp++) = (char*)(SCM_LIST_STR+1);
             break;
 
         case GH_TYPE_NUMBER:
@@ -157,12 +152,12 @@ run_printf(char const * pzFmt, int len, SCM alist)
             break;
 
         case GH_TYPE_PROCEDURE:
-            *(argp++) = (char*)"(*)()";
+            *(argp++) = (char*)SCM_PROC_CAST;
             break;
 
         case GH_TYPE_VECTOR:
         case GH_TYPE_LIST:
-            *(argp++) = (char*)"...";
+            *(argp++) = (char*)SCM_LIST_STR;
             break;
         }
     }
@@ -199,7 +194,7 @@ SCM
 ag_scm_sprintf(SCM fmt, SCM alist)
 {
     int   list_len = scm_ilength(alist);
-    char* pzFmt    = ag_scm2zchars(fmt, zFormat);
+    char* pzFmt    = ag_scm2zchars(fmt, WORD_FORMAT);
 
     if (list_len <= 0)
         return fmt;
@@ -225,7 +220,7 @@ SCM
 ag_scm_printf(SCM fmt, SCM alist)
 {
     int   list_len = scm_ilength(alist);
-    char* pzFmt    = ag_scm2zchars(fmt, zFormat);
+    char* pzFmt    = ag_scm2zchars(fmt, WORD_FORMAT);
 
     AG_SCM_DISPLAY(run_printf(pzFmt, list_len, alist));
     return SCM_UNDEFINED;
@@ -249,7 +244,7 @@ SCM
 ag_scm_fprintf(SCM port, SCM fmt, SCM alist)
 {
     int   list_len = scm_ilength(alist);
-    char* pzFmt    = ag_scm2zchars(fmt, zFormat);
+    char* pzFmt    = ag_scm2zchars(fmt, WORD_FORMAT);
     SCM   res      = run_printf(pzFmt, list_len, alist);
 
     return  scm_display(res, port);
@@ -271,42 +266,31 @@ ag_scm_fprintf(SCM port, SCM fmt, SCM alist)
 SCM
 ag_scm_hide_email(SCM display, SCM eaddr)
 {
-    static char const zFmt[]   = "&#%d;";
-    static char const zStrt[]  =
-        "<script language=\"JavaScript\" type=\"text/javascript\">\n"
-        "<!--\n"
-        "var one = 'm&#97;';\n"
-        "var two = 'i&#108;t';\n"
-        "document.write('<a href=\"' + one + two );\n"
-        "document.write('&#111;:";
+    char*  pzDisp  = ag_scm2zchars(display, "fmt");
+    char*  pzEadr  = ag_scm2zchars(eaddr,   "fmt");
+    size_t st_len  = HIDE_EMAIL_START_STR_LEN;
+    size_t end_len = HIDE_EMAIL_END_FMT_LEN;
 
-    static char const zEnd[]   = "');\n"
-        "document.write('\" >%s</a>');\n"
-        "//-->\n</script>";
-
-    char*  pzDisp = ag_scm2zchars(display, zFormat);
-    char*  pzEadr = ag_scm2zchars(eaddr,   zFormat);
-    size_t str_size = (strlen(pzEadr) * sizeof(zFmt))
-            + sizeof(zStrt) + sizeof(zEnd) + strlen(pzDisp);
+    size_t str_size = (strlen(pzEadr) * HTML_DEC_DIGIT_LEN)
+            + st_len + end_len + strlen(pzDisp);
 
     char*  pzRes  = ag_scribble(str_size);
     char*  pzScan = pzRes;
 
-    strcpy(pzScan, zStrt);
-    pzScan += sizeof(zStrt) - 1;
+    memcpy(pzScan, HIDE_EMAIL_START_STR, st_len);
+    pzScan += st_len;
 
     for (;;) {
         if (*pzEadr == NUL)
             break;
-        pzScan += sprintf(pzScan, zFmt, *(pzEadr++));
+        pzScan += sprintf(pzScan, HTML_DEC_DIGIT, *(pzEadr++));
     }
 
-    pzScan += sprintf(pzScan, zEnd, pzDisp);
+    pzScan += sprintf(pzScan, HIDE_EMAIL_END_FMT, pzDisp);
 
     return AG_SCM_STR2SCM(pzRes, (size_t)(pzScan - pzRes));
 }
 
-
 /*=gfunc   format_arg_count
  *
  * what:   count the args to a format
@@ -337,7 +321,7 @@ ag_scm_hide_email(SCM display, SCM eaddr)
 SCM
 ag_scm_format_arg_count(SCM fmt)
 {
-    char* pzFmt = ag_scm2zchars(fmt, zFormat);
+    char* pzFmt = ag_scm2zchars(fmt, WORD_FORMAT);
     int   ct    = 0;
     for (;;) {
         switch (*(pzFmt++)) {
