@@ -2,13 +2,13 @@
 /**
  * @file expString.c
  *
- *  Time-stamp:        "2011-08-02 12:21:12 bkorb"
+ *  Time-stamp:        "2012-02-12 09:01:34 bkorb"
  *
  *  This module implements expression functions that
  *  manipulate string values.
  *
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2012 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -32,22 +32,22 @@ static SCM
 makeString(char const * pzText, char const * pzNewLine, size_t newLineSize);
 
 static size_t
-stringify_for_sh(char * pzNew, u_int qt, char const * pzDta, size_t dtaSize);
+stringify_for_sh(char * pzNew, uint_t qt, char const * pzDta, size_t dtaSize);
 
 static SCM
-shell_stringify(SCM obj, u_int qt);
+shell_stringify(SCM obj, uint_t qt);
 
 static int
 sub_count(char const * haystack, char const * needle);
 
 static void
 do_substitution(
-    char const * pzStr,
-    size_t       strLen,
+    char const * src_str,
+    ssize_t      str_len,
     SCM          match,
     SCM          repl,
-    char **      ppzRes,
-    size_t *     pResLen);
+    char **      ppz_res,
+    ssize_t *    res_len);
 /* = = = END-STATIC-FORWARD = = = */
 
 static size_t
@@ -56,7 +56,7 @@ string_size(char const * pzScn, size_t newLineSize)
     /*
      *  Start by counting the start and end quotes, plus the NUL.
      */
-    size_t dtaSize = sizeof("\"\"");
+    size_t dtaSize = 3;
 
     for (;;) {
         char ch = *(pzScn++);
@@ -188,16 +188,13 @@ makeString(char const * pzText, char const * pzNewLine, size_t newLineSize)
             break;
 
         default:
-        {
-            static char const zFmt[] = "\\%03o";
             /*
              *  sprintf is safe here, because we already computed
              *  the amount of space we will be using.
              */
-            sprintf(pzDta, zFmt, ch);
+            sprintf(pzDta, MK_STR_OCT_FMT, ch);
             pzDta += 4;
         }
-        }
 
         pzScn++;
     } copyDone:
@@ -219,7 +216,7 @@ makeString(char const * pzText, char const * pzNewLine, size_t newLineSize)
 }
 
 static size_t
-stringify_for_sh(char * pzNew, u_int qt, char const * pzDta, size_t dtaSize)
+stringify_for_sh(char * pzNew, uint_t qt, char const * pzDta, size_t dtaSize)
 {
     char * pz = pzNew;
     *(pz++) = qt;
@@ -281,7 +278,7 @@ stringify_for_sh(char * pzNew, u_int qt, char const * pzDta, size_t dtaSize)
 }
 
 static SCM
-shell_stringify(SCM obj, u_int qt)
+shell_stringify(SCM obj, uint_t qt)
 {
     char*  pzNew;
     size_t dtaSize = 3;
@@ -329,58 +326,64 @@ sub_count(char const * haystack, char const * needle)
     return repCt;
 }
 
-/* * * * *
+/**
+ *  Replace marker text.
  *
- *  Substitution routines.  These routines implement a sed-like
- *  experience, except that we don't use regex-es.  It is straight
- *  text substitution.
+ *  Replace all occurrances of the marker text with the substitution text.
+ *  The result is stored in an automatically freed temporary buffer.
+ *
+ *  @param src_str  The source string
+ *  @param str_len  The length of the string
+ *  @param match    the SCM-ized marker string
+ *  @param repl     the SCM-ized replacement string
+ *  @param ppz_res  pointer to the result pointer
+ *  @param res_len  pointer to result length
  */
 static void
 do_substitution(
-    char const * pzStr,
-    size_t       strLen,
+    char const * src_str,
+    ssize_t      str_len,
     SCM          match,
     SCM          repl,
-    char **      ppzRes,
-    size_t *     pResLen)
+    char **      ppz_res,
+    ssize_t *    res_len)
 {
-    char* pzMatch = ag_scm2zchars(match, "match text");
-    char* pzRepl  = ag_scm2zchars(repl,  "repl text");
-    int   matchL  = AG_SCM_STRLEN(match);
-    int   replL   = AG_SCM_STRLEN(repl);
-    int   endL    = strLen;
+    char* pzMatch  = ag_scm2zchars(match, "match text");
+    char* rep_str  = ag_scm2zchars(repl,  "repl text");
+    int   mark_len = AG_SCM_STRLEN(match);
+    int   repl_len = AG_SCM_STRLEN(repl);
 
-    int   repCt   = sub_count(pzStr, pzMatch);
-    char const * pz = pzStr;
-    char * pzRes;
-    char * pzScan;
+    {
+        int ct = sub_count(src_str, pzMatch);
+        if (ct == 0)
+            return; /* No substitutions -- no work. */
 
-    /*
-     *  No substitutions -- no work.  The caller will have to track
-     *  whether or not to deallocate the result.
-     */
-    if (repCt == 0)
-        return;
+        str_len += (repl_len - mark_len) * ct;
+    }
 
-    endL   = endL + (replL * repCt) - (matchL * repCt);
-    pzScan = pzRes = ag_scribble(endL + 1);
-    pz     = pzStr;
+    {
+        char * dest = ag_scribble(str_len + 1);
+        *ppz_res = dest;
+        *res_len = str_len;
 
-    for (;;) {
-        char const * pzNxt = strstr(pz, pzMatch);
-        if (pzNxt == NULL)
-            break;
-        if (pz != pzNxt) {
-            memcpy(pzScan, pz, (size_t)(pzNxt - pz));
-            pzScan += (pzNxt - pz);
+        for (;;) {
+            char const * next = strstr(src_str, pzMatch);
+            size_t len;
+
+            if (next == NULL)
+                break;
+            len = next - src_str;
+            if (len != 0) {
+                memcpy(dest, src_str, len);
+                dest += len;
+            }
+            memcpy(dest, rep_str, (size_t)repl_len);
+            dest   += repl_len;
+            src_str = next + mark_len;
         }
-        memcpy(pzScan, pzRepl, (size_t)replL);
-        pzScan += replL;
-        pz = pzNxt + matchL;
+
+        strcpy(dest, src_str);
     }
-    strcpy(pzScan, pz);
-    *ppzRes = pzRes;
-    *pResLen = (pzScan - pzRes) + strlen(pz);
 }
 
 
@@ -391,7 +394,7 @@ do_substitution(
  *  The "match" and "repl" trees *must* be identical in structure.
  */
 LOCAL void
-do_multi_subs(char ** ppzStr, size_t * pStrLen, SCM match, SCM repl)
+do_multi_subs(char ** ppzStr, ssize_t * pStrLen, SCM match, SCM repl)
 {
     char* pzStr = *ppzStr;
     char* pzNxt = pzStr;
@@ -632,9 +635,9 @@ ag_scm_prefix(SCM prefix, SCM text)
     size_t   pfx_size;
     char*    pzRes;
 
-    pzPfx   = ag_scm2zchars(prefix, "prefix");
-    pzDta   = \
-    pzText  = ag_scm2zchars(text, "text");
+    pzPfx    = ag_scm2zchars(prefix, "prefix");
+    pzDta    = \
+    pzText   = ag_scm2zchars(text, "text");
     pfx_size = strlen(pzPfx);
     out_size = pfx_size;
 
@@ -662,7 +665,7 @@ ag_scm_prefix(SCM prefix, SCM text)
         switch (ch) {
         case NUL:
             if (rem_size != 0)
-                AG_ABEND("(prefix ...) failed");
+                AG_ABEND(PREFIX_FAIL);
 
             return AG_SCM_STR2SCM(pzRes, out_size);
 
@@ -681,74 +684,6 @@ ag_scm_prefix(SCM prefix, SCM text)
     }
 }
 
-
-/*=gfunc shell
- *
- * what:  invoke a shell script
- * general_use:
- *
- * exparg: command, shell command - the result value is stdout
- *
- * doc:
- *  Generate a string by writing the value to
- *  a server shell and reading the output back in.  The template
- *  programmer is responsible for ensuring that it completes
- *  within 10 seconds.  If it does not, the server will be killed,
- *  the output tossed and a new server started.
- *
- *  NB:  This is the same server process used by the '#shell'
- *  definitions directive and backquoted @code{`} definitions.
- *  There may be left over state from previous shell expressions
- *  and the @code{`} processing in the declarations.  However, a
- *  @code{cd} to the original directory is always issued before
- *  the new command is issued.
-=*/
-SCM
-ag_scm_shell(SCM cmd)
-{
-    if (! AG_SCM_STRING_P(cmd))
-        return SCM_UNDEFINED;
-    {
-        char* pz = shell_cmd(ag_scm2zchars(cmd, "command"));
-        cmd   = AG_SCM_STR02SCM(pz);
-        AGFREE((void*)pz);
-        return cmd;
-    }
-}
-
-
-/*=gfunc shellf
- *
- * what:  format a string, run shell
- * general_use:
- *
- * exparg: format, formatting string
- * exparg: format-arg, list of arguments to formatting string, opt, list
- *
- * doc:  Format a string using arguments from the alist,
- *       then send the result to the shell for interpretation.
-=*/
-SCM
-ag_scm_shellf(SCM fmt, SCM alist)
-{
-    int   len = scm_ilength(alist);
-    char* pz;
-
-#ifdef DEBUG_ENABLED
-    if (len < 0)
-        AG_ABEND("invalid alist to shellf");
-#endif
-
-    pz  = ag_scm2zchars(fmt, "format");
-    fmt = run_printf(pz, len, alist);
-
-    pz  = shell_cmd(ag_scm2zchars(fmt, "shell script"));
-    fmt = AG_SCM_STR02SCM(pz);
-    AGFREE((void*)pz);
-    return fmt;
-}
-
-
 /*=gfunc raw_shell_str
  *
  * what:  single quote shell string
@@ -994,10 +929,8 @@ ag_scm_stack(SCM obj)
 SCM
 ag_scm_kr_string(SCM str)
 {
-    static char const zNewLine[] = "\\n\\\n";
-
-    return makeString(ag_scm2zchars(str, "string"),
-                      zNewLine, sizeof(zNewLine)-1);
+    return makeString(ag_scm2zchars(str, "str"),
+                      KR_STRING_NEWLINE, KR_STRING_NEWLINE_LEN);
 }
 
 
@@ -1023,10 +956,8 @@ ag_scm_kr_string(SCM str)
 SCM
 ag_scm_c_string(SCM str)
 {
-    static char const zNewLine[] = "\\n\"\n       \"";
-
-    return makeString(ag_scm2zchars(str, "string"),
-                      zNewLine, sizeof(zNewLine)-1);
+    return makeString(ag_scm2zchars(str, "str"),
+                      C_STRING_NEWLINE, C_STRING_NEWLINE_LEN);
 }
 
 
@@ -1052,8 +983,8 @@ ag_scm_string_tr_x(SCM str, SCM from_xform, SCM to_xform)
 {
     unsigned char ch_map[ 1 << 8 /* bits-per-byte */ ];
     int   i      = sizeof(ch_map) - 1;
-    char* pzFrom = ag_scm2zchars(from_xform, "string");
-    char* pzTo   = ag_scm2zchars(to_xform, "string");
+    char* pzFrom = ag_scm2zchars(from_xform, "str");
+    char* pzTo   = ag_scm2zchars(to_xform, "str");
 
     do  {
         ch_map[i] = i;
@@ -1101,7 +1032,6 @@ ag_scm_string_tr_x(SCM str, SCM from_xform, SCM to_xform)
     return str;
 }
 
-
 /*=gfunc string_tr
  *
  * what:  convert characters with new result
@@ -1122,7 +1052,6 @@ ag_scm_string_tr(SCM Str, SCM From, SCM To)
     return ag_scm_string_tr_x(res, From, To);
 }
 
-
 /*=gfunc string_substitute
  *
  * what:  multiple global replacements
@@ -1147,8 +1076,8 @@ SCM
 ag_scm_string_substitute(SCM Str, SCM Match, SCM Repl)
 {
     char const *  pzStr;
-    size_t len;
-    SCM    res;
+    ssize_t len;
+    SCM     res;
 
     if (! AG_SCM_STRING_P(Str))
         return SCM_UNDEFINED;
@@ -1165,7 +1094,6 @@ ag_scm_string_substitute(SCM Str, SCM Match, SCM Repl)
     return res;
 }
 
-
 /*=gfunc time_string_to_number
  *
  * what:   duration string to seconds
