@@ -1,13 +1,16 @@
 
-/*
- *  $Id: 4d5a608655c544c41dfdbfda992be307942f7cf4 $
+/**
+ * @file loadPseudo.c
  *
- *  Time-stamp:        "2007-11-12 22:33:59 bkorb"
+ *  Find the start and end macro markers.  In btween we must find the
+ *  "autogen" and "template" keywords, followed by any suffix specs.
+ *
+ *  Time-stamp:        "2012-01-29 07:34:52 bkorb"
  *
  *  This module processes the "pseudo" macro
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2012 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -23,47 +26,40 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/*
- *  loadPseudoMacro
- *
- *  Find the start and end macro markers.  In btween we must find the
- *  "autogen" and "template" keywords, followed by any suffix specs.
- */
 #define DEFINE_FSM
 #include "pseudo-fsm.h"
 
-tSCC zAgName[] = "autogen5";
-tSCC zTpName[] = "template";
-
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by mk-fwd */
-static tCC*
-doSchemeExpr( tCC* pzData, tCC* pzFileName );
+static char const *
+do_scheme_expr(char const * pzData, char const * pzFileName);
+
+static char const *
+handle_hash_line(char const * pz);
 
 static te_pm_event
-findTokenType( tCC**  ppzData, te_pm_state fsm_state );
+next_pm_token(char const ** ppzData, te_pm_state fsm_state, char const * fnm);
 
-static tCC*
-copyMarker( tCC* pzData, char* pzMark, size_t * pCt );
+static char const *
+copy_mark(char const * pzData, char* pzMark, size_t * pCt);
 /* = = = END-STATIC-FORWARD = = = */
 
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
- *  doSchemeExpr
+ *  do_scheme_expr
  *
  *  Process a scheme specification
  */
-static tCC*
-doSchemeExpr( tCC* pzData, tCC* pzFileName )
+static char const *
+do_scheme_expr(char const * pzData, char const * pzFileName)
 {
-    char*   pzEnd = (char*)pzData + strlen( pzData );
+    char*   pzEnd = (char*)pzData + strlen(pzData);
     char    ch;
     tMacro* pCM = pCurMacro;
     tMacro  mac = { (teFuncType)~0, 0, 0, 0, 0, 0, 0, NULL };
 
     mac.lineNo  = templLineNo;
-    pzEnd       = (char*)skipScheme( pzData, pzEnd );
+    pzEnd       = (char*)skipScheme(pzData, pzEnd);
     ch          = *pzEnd;
     *pzEnd      = NUL;
     pCurMacro   = &mac;
@@ -74,20 +70,20 @@ doSchemeExpr( tCC* pzData, tCC* pzFileName )
     pCurMacro = pCM;
     *pzEnd    = ch;
     while (pzData < pzEnd)
-        if (*(pzData++) == '\n')
+        if (*(pzData++) == NL)
             templLineNo++;
-    return (tCC*)pzEnd;
+    return (char const *)pzEnd;
 }
 
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
- *  skipSuffixSpec
+ *  do_suffix
  *
  *  Process a suffix specification
  */
-LOCAL tCC*
-doSuffixSpec(tCC * const pzData, tCC* pzFileName, int lineNo)
+LOCAL char const *
+do_suffix(char const * const pzData, char const * pzFileName, int lineNo)
 {
     /*
      *  The following is the complete list of POSIX required-to-be-legal
@@ -96,19 +92,16 @@ doSuffixSpec(tCC * const pzData, tCC* pzFileName, int lineNo)
      *  also allow a format specification to follow the suffix,
      *  separated by an '=' character.
      */
-    tSCC zEmptySpec[] = "Empty suffix format";
-
-    tOutSpec*  pOS;
-    tCC*       pzSfxFmt;
-    tCC*       pzResult;
-    size_t     spn;
-    static tOutSpec**  ppOSList = &pOutSpecList;
+    tOutSpec   *       pOS;
+    char const *       pzSfxFmt;
+    char const *       pzResult;
+    size_t             spn;
+    static tOutSpec ** ppOSList = &pOutSpecList;
 
     /*
      *  Skip over the suffix construct
      */
-    pzSfxFmt = pzData;
-    while (IS_SUFFIX_CHAR(*pzSfxFmt))  pzSfxFmt++;
+    pzSfxFmt = SPN_SUFFIX_CHARS(pzData);
 
     if (*pzSfxFmt != '=') {
         pzResult = pzSfxFmt;
@@ -118,15 +111,14 @@ doSuffixSpec(tCC * const pzData, tCC* pzFileName, int lineNo)
         pzSfxFmt++;
 
         if (*pzSfxFmt == '(') {
-            tCC *pe  = pzSfxFmt + strlen( pzSfxFmt );
-            pzResult = skipScheme( pzSfxFmt, pe );
+            char const *pe  = pzSfxFmt + strlen(pzSfxFmt);
+            pzResult = skipScheme(pzSfxFmt, pe);
 
         } else {
-            pzResult = pzSfxFmt;
-            while (IS_SUFFIX_FMT_CHAR(*pzResult)) pzResult++;
+            pzResult = SPN_SUFFIX_FMT_CHARS(pzSfxFmt);
 
             if (pzSfxFmt == pzResult)
-                AG_ABEND(zEmptySpec);
+                AG_ABEND(DO_SUFFIX_EMPTY);
         }
     }
 
@@ -137,7 +129,7 @@ doSuffixSpec(tCC * const pzData, tCC* pzFileName, int lineNo)
      */
     if (  (pzFileName != NULL)
        && (  (procState != PROC_STATE_LOAD_TPL)
-          || HAVE_OPT( SELECT_SUFFIX )))
+          || HAVE_OPT(SELECT_SUFFIX)))
         return pzResult;
 
     /*
@@ -151,9 +143,9 @@ doSuffixSpec(tCC * const pzData, tCC* pzFileName, int lineNo)
         pOS = AGALOC(sz, "Output Specification");
         memset(pOS, NUL, sz);
     }
+
     *ppOSList  = pOS;
-    ppOSList   = &pOS->pNext;
-    pOS->pNext = NULL;
+    ppOSList   = &pOS->pNext; /* NULL, from memset */
     memcpy(pOS->zSuffix, pzData, spn);
     pOS->zSuffix[spn] = NUL;
 
@@ -174,15 +166,15 @@ doSuffixSpec(tCC * const pzData, tCC* pzFileName, int lineNo)
             size_t str_length;
             char const * pz;
 
-            pzSfxFmt = pz = resolveSCM( str );
+            pzSfxFmt = pz = resolveSCM(str);
             str_length = strlen(pzSfxFmt);
 
             if (str_length == 0)
-                AG_ABEND(zEmptySpec);
-            while (IS_SUFFIX_FMT_CHAR(*pz))  pz++;
+                AG_ABEND(DO_SUFFIX_EMPTY);
+            pz = SPN_SUFFIX_FMT_CHARS(pz);
 
             if ((pz - pzSfxFmt) != str_length)
-                AG_ABEND(aprf("invalid chars in suffix format:  %s", pz));
+                AG_ABEND(aprf(DO_SUFFIX_BAD_CHARS, pz));
 
             /*
              *  IF the scheme replacement text fits in the space, don't
@@ -201,26 +193,63 @@ doSuffixSpec(tCC * const pzData, tCC* pzFileName, int lineNo)
          *  IF the suffix does not start with punctuation,
          *  THEN we will insert a '.' of our own.
          */
-        if (IS_VAR_FIRST_CHAR(pOS->zSuffix[0]))
-             pOS->pzFileFmt = zFileFormat + 5;
-        else pOS->pzFileFmt = zFileFormat;
+        pOS->pzFileFmt = IS_VAR_FIRST_CHAR(pOS->zSuffix[0])
+            ? DOT_SFX_FMT : SFX_FMT;
     }
 
     return pzResult;
 }
 
+static char const *
+handle_hash_line(char const * pz)
+{
+    char const * res = strchr(pz, NL);
+    if (res == NULL)
+        AG_ABEND(HANDLE_HASH_BAD_TPL);
+
+    /*
+     *  If the comment starts with "#!/", then see if it names
+     *  an executable.  If it does, it is specifying a shell to use.
+     */
+    if ((pz[1] == '!') && (pz[2] == '/')) {
+        char const * pzScn = pz + 3;
+        char * nmbuf;
+        size_t len;
+
+        pzScn = SPN_FILE_NAME_CHARS(pzScn);
+
+        len   = pzScn - (pz + 2);
+        nmbuf = ag_scribble(len);
+        memcpy(nmbuf, pz+2, len);
+        nmbuf[len] = NUL;
+
+        /*
+         *  If we find the executable, then change the configured shell and
+         *  the SHELL environment variable to this executable.
+         */
+        if (access(nmbuf, X_OK) == 0) {
+            char * sp = malloc(len + 7); // len + "SHELL=" + NUL byte
+            sprintf(sp, HANDLE_HASH_ENV_FMT, HANDLE_HASH_SHELL, nmbuf);
+            putenv(sp);
+            AGDUPSTR(pzShellProgram, nmbuf, "prog shell");
+            AGDUPSTR(serverArgs[0],  nmbuf, "shell name");
+        }
+    }
+
+    return res;
+}
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
- *  findTokenType
+ *  next_pm_token
  *
  *  Skiping leading white space, figure out what sort of token is under
  *  the scan pointer (pzData).
  */
 static te_pm_event
-findTokenType( tCC**  ppzData, te_pm_state fsm_state )
+next_pm_token(char const ** ppzData, te_pm_state fsm_state, char const * fnm)
 {
-    tCC* pzData = *ppzData;
+    char const * pzData = *ppzData;
 
     /*
      *  At the start of processing in this function, we can never be at
@@ -232,7 +261,7 @@ findTokenType( tCC**  ppzData, te_pm_state fsm_state )
 
  skipWhiteSpace:
     while (IS_WHITESPACE_CHAR(*pzData)) {
-        if (*(pzData++) == '\n') {
+        if (*(pzData++) == NL) {
             line_start = AG_TRUE;
             templLineNo++;
 
@@ -248,9 +277,7 @@ findTokenType( tCC**  ppzData, te_pm_state fsm_state )
     }
 
     if (line_start && (*pzData == '#')) {
-        pzData = strchr( pzData, '\n' );
-        if (pzData == NULL)
-            AG_ABEND( "Invalid template file" );
+        pzData = handle_hash_line(pzData);
         goto skipWhiteSpace;
     }
 
@@ -268,22 +295,19 @@ findTokenType( tCC**  ppzData, te_pm_state fsm_state )
      *  THEN it must be "autogen5" or "template" or a suffix specification
      */
     if (IS_VAR_FIRST_CHAR(*pzData)) {
-        if (strneqvcmp( pzData, zAgName, (int)sizeof(zAgName)-1 ) == 0) {
-            if (IS_WHITESPACE_CHAR(pzData[ sizeof(zAgName)-1 ])) {
-                *ppzData = pzData + sizeof(zAgName);
+        if (strneqvcmp(pzData, AG_MARK, AG_MARK_LEN) == 0) {
+            if (IS_WHITESPACE_CHAR(pzData[ AG_MARK_LEN ])) {
+                *ppzData = pzData + AG_MARK_LEN + 1;
                 return PM_EV_AUTOGEN;
             }
 
             return PM_EV_SUFFIX;
         }
 
-        if (strneqvcmp( pzData, zTpName, (int)sizeof(zTpName)-1 ) == 0) {
-            if (IS_WHITESPACE_CHAR(pzData[ sizeof(zTpName)-1 ])) {
-                *ppzData = pzData + sizeof(zTpName)-1;
-                return PM_EV_TEMPLATE;
-            }
-
-            return PM_EV_SUFFIX;
+        if (  (strneqvcmp(pzData, TPL_MARK, TPL_MARK_LEN) == 0)
+           && (IS_WHITESPACE_CHAR(pzData[ TPL_MARK_LEN ])) ) {
+            *ppzData = pzData + TPL_MARK_LEN;
+            return PM_EV_TEMPLATE;
         }
 
         return PM_EV_SUFFIX;
@@ -315,27 +339,25 @@ findTokenType( tCC**  ppzData, te_pm_state fsm_state )
      *  IF it is some other punctuation,
      *  THEN it must be a start/end marker.
      */
-    if (IS_PUNCTUATION_CHAR( *pzData ))
+    if (IS_PUNCTUATION_CHAR(*pzData))
         return PM_EV_MARKER;
 
     /*
      *  Otherwise, it is just junk.
      */
-    AG_ABEND( "Invalid template file" );
+    AG_ABEND(aprf(NEXT_PM_TOKEN_INVALID, fnm));
     /* NOTREACHED */
     return PM_EV_INVALID;
 }
 
 
-/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- *
- *  copyMarker
- *
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
+/**
  *  Some sort of marker is under the scan pointer.  Copy it for as long
  *  as we find punctuation characters.
  */
-static tCC*
-copyMarker( tCC* pzData, char* pzMark, size_t * pCt )
+static char const *
+copy_mark(char const * pzData, char* pzMark, size_t * pCt)
 {
     int ct = 0;
 
@@ -344,7 +366,7 @@ copyMarker( tCC* pzData, char* pzMark, size_t * pCt )
         if (! IS_PUNCTUATION_CHAR(ch))
             break;
         *(pzMark++) = ch;
-        if (++ct >= sizeof( zStartMac ))
+        if (++ct >= sizeof(zStartMac))
             return NULL;
 
         pzData++;
@@ -354,33 +376,29 @@ copyMarker( tCC* pzData, char* pzMark, size_t * pCt )
     *pzMark = NUL;
 
     if (OPT_VALUE_TRACE >= TRACE_EXPRESSIONS)
-        fprintf(pfTrace, "marker ``%s'' loaded\n", pzMark - ct);
+        fprintf(pfTrace, TRACE_COPY_MARK, pzMark - ct);
 
     return pzData;
 }
 
 
-/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- *
- *  loadPseudoMacro
- *
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
+/**
  *  Using a finite state machine, scan over the tokens that make up the
  *  "pseudo macro" at the start of every template.
  */
-LOCAL tCC*
-loadPseudoMacro( tCC* pzData, tCC* pzFileName )
+LOCAL char const *
+loadPseudoMacro(char const * pzData, char const * pzFileName)
 {
-    tSCC zMarkErr[] = "start/end macro mark too long";
-    tSCC zBadMark[] = "bad template marker in %s on line %d:\n\t%s";
-    tCC* pzBadness;
-#   define BAD_MARKER( t ) { pzBadness = t; goto abort_load; }
+    char const * pzBadness;
+#   define BAD_MARKER(t) { pzBadness = t; goto abort_load; }
 
     te_pm_state fsm_state  = PM_ST_INIT;
 
     templLineNo  = 1;
 
     while (fsm_state != PM_ST_DONE) {
-        te_pm_event fsm_tkn = findTokenType( &pzData, fsm_state );
+        te_pm_event fsm_tkn = next_pm_token(&pzData, fsm_state, pzFileName);
         te_pm_state nxt_state;
         te_pm_trans trans;
 
@@ -395,26 +413,26 @@ loadPseudoMacro( tCC* pzData, tCC* pzFileName )
         switch (trans) {
         case PM_TR_SKIP_ED_MODE:
         {
-            char* pzEnd = strstr( pzData + 3, "-*-" );
-            char* pzNL  = strchr( pzData + 3, '\n' );
+            char* pzEnd = strstr(pzData + 3, PSEUDO_MAC_MODE_MARK);
+            char* pzNL  = strchr(pzData + 3, NL);
             if ((pzEnd == NULL) || (pzNL < pzEnd))
-                BAD_MARKER( "invalid edit mode marker" );
+                BAD_MARKER(PSEUDO_MAC_BAD_MODE);
 
             pzData = pzEnd + 3;
             break;
         }
 
         case PM_TR_INIT_MARKER:
-            pzData = copyMarker( pzData, zStartMac, &startMacLen );
+            pzData = copy_mark(pzData, zStartMac, &startMacLen);
             if (pzData == NULL)
-                BAD_MARKER( zMarkErr );
+                BAD_MARKER(PSEUDO_MAC_BAD_LENGTH);
 
             break;
 
         case PM_TR_TEMPL_MARKER:
-            pzData = copyMarker( pzData, zEndMac, &endMacLen );
+            pzData = copy_mark(pzData, zEndMac, &endMacLen);
             if (pzData == NULL)
-                BAD_MARKER( zMarkErr );
+                BAD_MARKER(PSEUDO_MAC_BAD_LENGTH);
 
             /*
              *  IF the end macro seems to end with the start macro and
@@ -422,68 +440,51 @@ loadPseudoMacro( tCC* pzData, tCC* pzFileName )
              *  presume that someone ran the two markers together.
              */
             if (  (endMacLen == 2 * startMacLen)
-               && (strcmp( zStartMac, zEndMac + startMacLen ) == 0))  {
+               && (strcmp(zStartMac, zEndMac + startMacLen) == 0))  {
                 pzData -= startMacLen;
                 zEndMac[ startMacLen ] = NUL;
                 endMacLen = startMacLen;
             }
 
-            if (strstr( zEndMac, zStartMac ) != NULL)
-                BAD_MARKER( "start marker contained in end marker" );
-            if (strstr( zStartMac, zEndMac ) != NULL)
-                BAD_MARKER( "end marker contained in start marker" );
+            if (strstr(zEndMac, zStartMac) != NULL)
+                BAD_MARKER(PSEUDO_MAC_BAD_ENDER);
+            if (strstr(zStartMac, zEndMac) != NULL)
+                BAD_MARKER(PSEUDO_MAC_BAD_STARTER);
             break;
 
         case PM_TR_TEMPL_SUFFIX:
-            pzData = doSuffixSpec( pzData, pzFileName, templLineNo );
+            pzData = do_suffix(pzData, pzFileName, templLineNo);
             break;
 
         case PM_TR_TEMPL_SCHEME:
-            pzData = doSchemeExpr( pzData, pzFileName );
+            pzData = do_scheme_expr(pzData, pzFileName);
             break;
 
         case PM_TR_INVALID:
-            pm_invalid_transition( fsm_state, fsm_tkn );
+            pm_invalid_transition(fsm_state, fsm_tkn);
             switch (fsm_state) {
-            case PM_ST_INIT:     BAD_MARKER( "need start marker" );
-            case PM_ST_ST_MARK:  BAD_MARKER( "need autogen5 marker" );
-            case PM_ST_AGEN:     BAD_MARKER( "need template marker" );
-            case PM_ST_TEMPL:    BAD_MARKER( "need end marker" );
-            case PM_ST_END_MARK: BAD_MARKER( "need end of line" );
-            default:             BAD_MARKER( "BROKEN FSM STATE" );
+            case PM_ST_INIT:     BAD_MARKER(PSEUDO_MAC_BAD_NOSTART);
+            case PM_ST_ST_MARK:  BAD_MARKER(PSEUDO_MAC_BAD_NOAG5);
+            case PM_ST_AGEN:     BAD_MARKER(PSEUDO_MAC_BAD_NOTPL);
+            case PM_ST_TEMPL:    BAD_MARKER(PSEUDO_MAC_BAD_NOEND);
+            case PM_ST_END_MARK: BAD_MARKER(PSEUDO_MAC_BAD_NOEOL);
+            default:             BAD_MARKER(PSEUDO_MAC_BAD_FSM);
             }
 
         case PM_TR_NOOP:
             break;
 
         default:
-            BAD_MARKER( "broken pseudo-macro FSM" );
+            BAD_MARKER(PSEUDO_MAC_BAD_PSEUDO);
         }
 
         fsm_state = nxt_state;
     }
 
-    /*
-     *  It is possible that the template writer specified a shell to use.
-     *  If the server shell has not already started, we'll catch it later.
-     *  If it has started, then check for a shell change & shut it down
-     *  if it has been changed.
-     */
-    if (serverArgs[0] != NULL) {
-        char* pz = getenv(zShellEnv);
-        if ((pz != NULL) && (strcmp( pz, serverArgs[0] ) != 0)) {
-            fprintf(pfTrace, "Changing server shell from %s to %s\n",
-                    serverArgs[0], pz);
-            closeServer();
-            serverArgs[0]  = pz;
-            pzShellProgram = pz;
-        }
-    }
-
     return pzData;
 
  abort_load:
-    AG_ABEND( aprf( zBadMark, pzFileName, templLineNo, pzBadness ));
+    AG_ABEND(aprf(PSEUDO_MAC_ERR_FMT, pzFileName, templLineNo, pzBadness));
 #   undef BAD_MARKER
     return NULL;
 }
