@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for agen5
- * Generated Sun Dec  4 07:09:20 PST 2011
+ * Generated Sun Feb 26 11:09:08 PST 2012
  */
 #ifndef AGEN5_PROTO_H_GUARD
 #define AGEN5_PROTO_H_GUARD 1
@@ -18,6 +18,27 @@
 LOCAL void
 loadCgi(void);
 
+/*
+ *  Extracted from agDep.c
+ */
+LOCAL void
+add_source_file(char const * pz);
+
+LOCAL void
+rm_source_file(char const * pz);
+
+LOCAL void
+add_target_file(char const * pz);
+
+LOCAL void
+rm_target_file(char const * pz);
+
+LOCAL void
+start_dep_file(void);
+
+LOCAL void
+wrap_up_depends(void);
+
 /*
  *  Extracted from agInit.c
  */
@@ -162,7 +183,7 @@ run_printf(char const * pzFmt, int len, SCM alist);
  *  Extracted from expString.c
  */
 LOCAL void
-do_multi_subs(char ** ppzStr, size_t * pStrLen, SCM match, SCM repl);
+do_multi_subs(char ** ppzStr, ssize_t * pStrLen, SCM match, SCM repl);
 
 /*
  *  Extracted from funcDef.c
@@ -221,9 +242,6 @@ findFile(char const * pzFName,
          char const * const * papSuffixList,
          char const * pzReferrer);
 
-LOCAL void
-append_source_name(char const * pz);
-
 LOCAL tTemplate *
 loadTemplate(char const * pzFileName, char const * referrer);
 
