@@ -1,8 +1,8 @@
 
-;;; Time-stamp:        "2011-11-23 10:34:40 bkorb"
+;;; Time-stamp:        "2012-01-07 09:25:09 bkorb"
 ;;;
 ;;; This file is part of AutoGen.
-;;; AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
+;;; AutoGen Copyright (c) 1992-2012 by Bruce Korb - all rights reserved
 ;;;
 ;;; AutoGen is free software: you can redistribute it and/or modify it
 ;;; under the terms of the GNU General Public License as published by the
@@ -21,6 +21,11 @@
 ;;; It gets sucked up into directives.h as a single ANSI-C string.
 ;;; Comments, blank lines and leading white space are omitted.
 ;;;
+;;; The contents of this file get converted to a C language static string
+;;; and is then fed to the guile library at start up time.
+;;; Blank lines, commends, leading and trailing white space and spaces
+;;; before closing parentheses are all stripped.
+;;;
 (use-modules (ice-9 common-list))
 
 (define identifier?
@@ -199,6 +204,10 @@
 ;;;  *
 ;;;  *   These functions use the global name space @code{stt-*} in addition to
 ;;;  *   the function names.
+;;;  *
+;;;  *   If you utilize this in your programming, it is recommended that you
+;;;  *   prevent printf format usage warnings with the GCC option
+;;;  *   @code{-Wno-format-contains-nul}
 ;;; =*/
 ;;;
 (define string-table-new (lambda (st-name) (begin
@@ -290,7 +299,10 @@
    ;; End the last line with a semi-colon
    ;;
    (emit (shell (string-append
-     "sed 's/^ /      /;s/\" \"\\\\0/\\\\0/;$s/$/;/' <<\\_EOF_\n"
+     "sed 's/^ /      /
+	$s/\" \"\\\\0\"/\";/
+	s/\" \"\\\\0/\\\\0/
+	' <<\\_EOF_\n"
      (out-pop #t)
      "_EOF_")))
    (emit "\n")
