@@ -1,13 +1,13 @@
 
 /**
- *  \file scmStrings.c
+ * @file scmStrings.c
  *
  *  Temporary SCM strings.
  *
- * Time-stamp:        "2010-12-09 15:01:34 bkorb"
+ * Time-stamp:        "2012-01-29 09:48:03 bkorb"
  *
  * This file is part of AutoGen.
- * AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
+ * AutoGen Copyright (c) 1992-2012 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -96,7 +96,7 @@ new_scribble_block(size_t min_size)
     /*
      * Allocate and link into list.  Advance pointer to next entry.
      */
-    *next_strbuf = res = AGALOC(min_size, "SCM String Buffer");
+    *next_strbuf = res = AGALOC(min_size, "scribble buf");
     next_strbuf  = &(res->next_p);
     res->next_p  = NULL;
     res->sb_off  = 0;
@@ -117,8 +117,11 @@ new_scribble_block(size_t min_size)
  *  the space to still be usable at the end of the block macro.
  *  These allocations are intended for temporary space needs that cannot
  *  be kept on the stack.  Expression processing.
+ *
+ *  @param  size  the number of bytes needed
+ *  @return the memory as a pointer to character
  */
-LOCAL char*
+LOCAL char *
 ag_scribble(ssize_t size)
 {
     string_buf_t* sb = ag_strbufs;
@@ -144,27 +147,28 @@ ag_scribble(ssize_t size)
     return buf;
 }
 
-
-#if GUILE_VERSION >= 107000
 /**
  *  As of Guile 1.7.x, access to the NUL terminated string referenced by
  *  an SCM is no longer guaranteed.  Therefore, we must extract the string
  *  into one of our "scribble" buffers.
  *
- * @param s the string to convert
- * @param type a string describing the string
- * @returns a NUL terminated string, or it aborts.
+ * @param  s     the string to convert
+ * @param  type  a string describing the string
+ * @return a NUL terminated string, or it aborts.
  */
-char *
+LOCAL char *
 ag_scm2zchars(SCM s, const char * type)
 {
-    static char const bad_val[] =
-        "scm_string_length returned wrong value: %d != %d\n";
+#if GUILE_VERSION < 107000  /* pre-Guile 1.7.x */
+#   error Your Guile is too old.
+    choke me.
+
+#else
     size_t len;
     char * buf;
 
     if (! AG_SCM_STRING_P(s))
-        AG_ABEND(aprf("%s is not a string", type));
+        AG_ABEND(aprf(NOT_STR_FMT, type));
 
     len = scm_c_string_length(s);
     if (len == 0) {
@@ -177,13 +181,13 @@ ag_scm2zchars(SCM s, const char * type)
     {
         size_t buflen = scm_to_locale_stringbuf(s, buf, len);
         if (buflen != len)
-            AG_ABEND(aprf(bad_val, buflen, len));
+            AG_ABEND(aprf(SCM2ZCHARS_BAD_VAL, buflen, len));
     }
 
     buf[len] = NUL;
     return buf;
-}
 #endif
+}
 
 /*
  * Local Variables:
