@@ -2,11 +2,11 @@
 
 ## texi2mdoc.sh -- script to convert texi-isms to mdoc-isms
 ##
-## Time-stamp:      "2011-03-30 15:13:15 bkorb"
+## Time-stamp:      "2012-02-25 12:54:32 bkorb"
 ##
 ##  This file is part of AutoOpts, a companion to AutoGen.
 ##  AutoOpts is free software.
-##  AutoOpts is Copyright (c) 1992-2011 Bruce Korb - all rights reserved
+##  AutoOpts is Copyright (c) 1992-2012 Bruce Korb - all rights reserved
 ##
 ##  AutoOpts is available under any one of two licenses.  The license
 ##  in use must be one of these two and the choice is under the control
@@ -133,6 +133,7 @@ do_item() {
 
 do_line() {
     case "${line}" in
+    '@subheading*' ) echo "$line" | sed 's/@subheading/.SS /' ;;
     '@*' ) echo .br ;;
     ''   ) echo .sp ;;
     '@'[{}]* ) echo "${line}" | sed 's/@\([{}]\)/\1/g' ;;
@@ -150,25 +151,27 @@ do_line() {
     return 0
 }
 
-fixfont='
-s;@code{\([^}]*\)};\\fB\1\\fP;g
-s;@var{\([^}]*\)};\\fB\1\\fP;g
-s;@samp{\([^}]*\)};\\fB\1\\fP;g
-s;@i{\([^}]*\)};\\fI\1\\fP;g
-s;@file{\([^}]*\)};\\fI\1\\fP;g
-s;@emph{\([^}]*\)};\\fI\1\\fP;g
-s;@strong{\([^}]*\)};\\fB\1\\fP;g
-s;@pxref{\([^}]*\)};see: \1;g
-s;@xref{\([^}]*\)};see: \1;g
-s/@\([{@}]\)/\1/g
-s,^[@$]\*$,.br,
-s/\*\([a-zA-Z0-9:~=_ -]*\)\*/\\fB\1\\fP/g
-s/``\([a-zA-Z0-9:~+=_ -]*\)'\'\''/\\(lq\1\\(rq/g
-s/\([^\\]\)-/\1\\-/g
-s/\([^\\]\)-/\1\\-/g
-/^\.\(Bl\|Bd\|in\) /s/ \\-/ -/g'"
-s/^'/\\'/
-/^$/d"
+
+bold='\(code\|command\|var\|samp\|option\|strong\)'
+bold="s;@${bold}"'{\([^}]*\)};\\fB\2\\fP;g'
+
+ital='\(i\|file\|emph\)'
+ital="s;@${ital}"'{\([^}]*\)};\\fI\2\\fP;g'
+nl='
+'
+
+fixfont="${bold}${nl}${ital}"'
+	s;@pxref{\([^}]*\)};see: \1;g
+	s;@xref{\([^}]*\)};see: \1;g
+	s/@\([{@}]\)/\1/g
+	s,^[@$]\*$,.br,
+	s/\*\([a-zA-Z0-9:~=_ -]*\)\*/\\fB\1\\fP/g
+	s/``\([a-zA-Z0-9:~+=_ -]*\)'\'\''/\\(lq\1\\(rq/g
+	s/\([^\\]\)-/\1\\-/g
+	s/\([^\\]\)-/\1\\-/g
+	/^\.\(Bl\|Bd\|in\) /s/ \\-/ -/g'"
+	s/^'/\\\\'/
+	/^\$/d"
 readonly fixfont
 
 {
